==> firelamp-0.0.3.tar.gz: lib/widgets/forum/comment/comment_list.dart <==
import 'package:firelamp/widgets/defines.dart';
import 'package:flutter/material.dart';
import 'package:firelamp/firelamp.dart';

import 'package:firelamp/widgets/forum/comment/comment_view.dart';

class CommentList extends StatefulWidget {
  CommentList({
    this.post,
    this.forum,
    this.onError,
  });
  final ApiPost post;
  final ApiForum forum;
  final Function onError;

  @override
  _CommentListState createState() => _CommentListState();
}

class _CommentListState extends State<CommentList> {
  String get listText {
    final commentCount = widget.post.comments.length;
    final text = '$commentCount comment';
    return commentCount > 1 ? text + 's' : text;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: widget.post.comments.isNotEmpty
          ? Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: [
                SizedBox(height: Space.xsm),
                Text(
                  listText,
                  style: TextStyle(fontSize: Space.xsm, color: Colors.grey[500]),
                ),
                for (ApiComment comment in widget.post.comments)
                  CommentView(
                    comment: comment,
                    post: widget.post,
                    forum: widget.forum,
                    onError: widget.onError,
                    onCommentEditSuccess: () => setState(() {}),
                    onCommentDeleteSuccess: () =>  setState(() {}),
                  ),
              ],
            )
          : Padding(
              padding: EdgeInsets.only(top: Space.xsm, left: Space.xsm),
              child: Text(
                'No comments yet ..',
                style: TextStyle(fontSize: Space.xsm, color: Colors.grey[500]),
              ),
            ),
    );
  }
}

==> firelamp-0.0.6.tar.gz: lib/widgets/forum/comment/comment_list.dart <==
import 'package:firelamp/widgets/defines.dart';
import 'package:flutter/material.dart';
import 'package:firelamp/firelamp.dart';

import 'package:firelamp/widgets/forum/comment/comment_view.dart';
import 'package:get/get.dart';

class CommentList extends StatefulWidget {
  CommentList({
    this.post,
    this.forum,
    this.onError,
  });
  final ApiPost post;
  final ApiForum forum;
  final Function onError;

  @override
  _CommentListState createState() => _CommentListState();
}

class _CommentListState extends State<CommentList> {
  String get listText {
    final commentCount = widget.post.comments.length;
    final text = '$commentCount comment';
    return commentCount > 1 ? text + 's' : text;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: widget.post.comments.isNotEmpty
          ? Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: [
                SizedBox(height: Space.xsm),
                Text(
                  listText,
                  style:
                      TextStyle(fontSize: Space.xsm, color: Colors.grey[500]),
                ),
                for (ApiComment comment in widget.post.comments)
                  CommentView(
                    comment: comment,
                    post: widget.post,
                    forum: widget.forum,
                    onError: widget.onError,
                    onCommentEditSuccess: () => setState(() {}),
                    onCommentDeleteSuccess: () => setState(() {}),
                  ),
              ],
            )
          : Padding(
              padding: EdgeInsets.only(top: Space.xsm, left: Space.xsm),
              child: Text(
                'No comments yet'.tr,
                style: TextStyle(fontSize: Space.xsm, color: Colors.grey[500]),
              ),
            ),
    );
  }
}
